==> haskell-dbus0.10-0.10.15-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dbus0.10.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dbus
version: 0.10.15
id: dbus-0.10.15-Fqw2MahdXJc9KOhrgDEkWB
key: dbus-0.10.15-Fqw2MahdXJc9KOhrgDEkWB
license: GPL-3
maintainer: Andrey Sverdlichenko <blaze@ruddy.ru>
stability: experimental
homepage: https://github.com/rblaze/haskell-dbus#readme
synopsis: A client library for the D-Bus IPC system.
description:
    D-Bus is a simple, message-based protocol for inter-process
    communication, which allows applications to interact with other parts of
    the machine and the user'\''s session using remote procedure calls.
    .
    D-Bus is a essential part of the modern Linux desktop, where it replaces
    earlier protocols such as CORBA and DCOP.
    .
    This library is an implementation of the D-Bus protocol in Haskell. It
    can be used to add D-Bus support to Haskell applications, without the
    awkward interfaces common to foreign bindings.
    .
    Example: connect to the session bus, and get a list of active names.
    .
    @
    &#x7b;-\# LANGUAGE OverloadedStrings \#-&#x7d;
    .
    import Data.List (sort)
    import DBus
    import DBus.Client
    .
    main = do
    &#x20;   client <- connectSession
    &#x20;   //
    &#x20;   \-- Request a list of connected clients from the bus
    &#x20;   reply <- call_ client (methodCall \"\/org\/freedesktop\/DBus\" \"org.freedesktop.DBus\" \"ListNames\")
    &#x20;       &#x7b; methodCallDestination = Just \"org.freedesktop.DBus\"
    &#x20;       &#x7d;
    &#x20;   //
    &#x20;   \-- org.freedesktop.DBus.ListNames() returns a single value, which is
    &#x20;   \-- a list of names (here represented as [String])
    &#x20;   let Just names = fromVariant (methodReturnBody reply !! 0)
    &#x20;   //
    &#x20;   \-- Print each name on a line, sorted so reserved names are below
    &#x20;   \-- temporary names.
    &#x20;   mapM_ putStrLn (sort names)
    @
    .
    >$ ghc --make list-names.hs
    >$ ./list-names
    >:1.0
    >:1.1
    >:1.10
    >:1.106
    >:1.109
    >:1.110
    >ca.desrt.dconf
    >org.freedesktop.DBus
    >org.freedesktop.Notifications
    >org.freedesktop.secrets
    >org.gnome.ScreenSaver
category: Network, Desktop
author: John Millikin <john@john-millikin.com>
exposed: True
indefinite: False
exposed-modules:
    DBus DBus.Client DBus.Internal.Address DBus.Internal.Message
    DBus.Internal.Types DBus.Internal.Wire DBus.Introspection
    DBus.Socket DBus.Transport
abi: a0f57e754e751739870da7957330ead9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/dbus-0.10.15
library-dirs: /usr/lib/ghc-8.2.2/site-local/dbus-0.10.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/dbus-0.10.15
hs-libraries: HSdbus-0.10.15-Fqw2MahdXJc9KOhrgDEkWB
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I containers-0.5.10.2
    deepseq-1.4.3.0 libxml-sax-0.7.5-FejhMvuTvxT64dOEVQOQrU
    network-2.6.3.5-HciQ97zzdTVSLyOa0zOYp
    parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj transformers-0.5.2.0
    unix-2.7.2.2 vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    xml-types-0.3.6-8WPJEemJnrZwepJreraPY
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I=bbc9fd83dce68f46a0ca98edbf2c2923
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             libxml-sax-0.7.5-FejhMvuTvxT64dOEVQOQrU=7bf5d226f2215e913eac1b9852a4b6f7
             network-2.6.3.5-HciQ97zzdTVSLyOa0zOYp=e81ab755128c48e8082525402fc065c2
             parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F=688f5e7444a80128e4a1c39bd128d195
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             xml-types-0.3.6-8WPJEemJnrZwepJreraPY=7e7faac838649cb4151c9d4e8edfc9dc
haddock-interfaces: /usr/share/doc/haskell-dbus0.10/html/dbus.haddock
haddock-html: /usr/share/doc/haskell-dbus0.10/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dbus0.10-0.10.15-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dbus0.10.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dbus
version: 0.10.15
id: dbus-0.10.15-19cYrBOj7vPAYcTHOr493F
key: dbus-0.10.15-19cYrBOj7vPAYcTHOr493F
license: GPL-3
maintainer: Andrey Sverdlichenko <blaze@ruddy.ru>
stability: experimental
homepage: https://github.com/rblaze/haskell-dbus#readme
synopsis: A client library for the D-Bus IPC system.
description:
    D-Bus is a simple, message-based protocol for inter-process
    communication, which allows applications to interact with other parts of
    the machine and the user'\''s session using remote procedure calls.
    .
    D-Bus is a essential part of the modern Linux desktop, where it replaces
    earlier protocols such as CORBA and DCOP.
    .
    This library is an implementation of the D-Bus protocol in Haskell. It
    can be used to add D-Bus support to Haskell applications, without the
    awkward interfaces common to foreign bindings.
    .
    Example: connect to the session bus, and get a list of active names.
    .
    @
    &#x7b;-\# LANGUAGE OverloadedStrings \#-&#x7d;
    .
    import Data.List (sort)
    import DBus
    import DBus.Client
    .
    main = do
    &#x20;   client <- connectSession
    &#x20;   //
    &#x20;   \-- Request a list of connected clients from the bus
    &#x20;   reply <- call_ client (methodCall \"\/org\/freedesktop\/DBus\" \"org.freedesktop.DBus\" \"ListNames\")
    &#x20;       &#x7b; methodCallDestination = Just \"org.freedesktop.DBus\"
    &#x20;       &#x7d;
    &#x20;   //
    &#x20;   \-- org.freedesktop.DBus.ListNames() returns a single value, which is
    &#x20;   \-- a list of names (here represented as [String])
    &#x20;   let Just names = fromVariant (methodReturnBody reply !! 0)
    &#x20;   //
    &#x20;   \-- Print each name on a line, sorted so reserved names are below
    &#x20;   \-- temporary names.
    &#x20;   mapM_ putStrLn (sort names)
    @
    .
    >$ ghc --make list-names.hs
    >$ ./list-names
    >:1.0
    >:1.1
    >:1.10
    >:1.106
    >:1.109
    >:1.110
    >ca.desrt.dconf
    >org.freedesktop.DBus
    >org.freedesktop.Notifications
    >org.freedesktop.secrets
    >org.gnome.ScreenSaver
category: Network, Desktop
author: John Millikin <john@john-millikin.com>
exposed: True
indefinite: False
exposed-modules:
    DBus DBus.Client DBus.Internal.Address DBus.Internal.Message
    DBus.Internal.Types DBus.Internal.Wire DBus.Introspection
    DBus.Socket DBus.Transport
abi: 313f7993bb23f137779eda2052795132
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/dbus-0.10.15
library-dirs: /usr/lib/ghc-8.2.2/site-local/dbus-0.10.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/dbus-0.10.15
hs-libraries: HSdbus-0.10.15-19cYrBOj7vPAYcTHOr493F
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I containers-0.5.10.2
    deepseq-1.4.3.0 libxml-sax-0.7.5-FejhMvuTvxT64dOEVQOQrU
    network-2.6.3.5-HciQ97zzdTVSLyOa0zOYp
    parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj transformers-0.5.2.0
    unix-2.7.2.2 vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    xml-types-0.3.6-8WPJEemJnrZwepJreraPY
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             cereal-0.5.5.0-DWUgAsuwqXgLl3Helfg18I=bbc9fd83dce68f46a0ca98edbf2c2923
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             libxml-sax-0.7.5-FejhMvuTvxT64dOEVQOQrU=7bf5d226f2215e913eac1b9852a4b6f7
             network-2.6.3.5-HciQ97zzdTVSLyOa0zOYp=e81ab755128c48e8082525402fc065c2
             parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F=688f5e7444a80128e4a1c39bd128d195
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=bddaa4d6513f513fbc23673a7214617b
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             unix-2.7.2.2=1e3caa57de79efd01f1c7566785dcafa
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
             xml-types-0.3.6-8WPJEemJnrZwepJreraPY=7e7faac838649cb4151c9d4e8edfc9dc
haddock-interfaces: /usr/share/doc/haskell-dbus0.10/html/dbus.haddock
haddock-html: /usr/share/doc/haskell-dbus0.10/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
